==> generator-knockout-bootstrap-0.0.1.tgz: package/README.md <==
# generator-knockout-bootstrap [![Build Status](https://secure.travis-ci.org/leszekhanusz/generator-knockout-bootstrap.png?branch=master)](https://travis-ci.org/leszekhanusz/generator-knockout-bootstrap)

> [Yeoman](http://yeoman.io) generator for Knockout.js with Twitter Bootstrap


## Getting Started

### What is Yeoman?

Trick question. It's not a thing. It's this guy:

![](http://i.imgur.com/JHaAlBJ.png)

Basically, he wears a top hat, lives in your computer, and waits for you to tell him what kind of application you wish to create.

Not every new computer comes with a Yeoman pre-installed. He lives in the [npm](https://npmjs.org) package repository. You only have to ask for him once, then he packs up and moves into your hard drive. *Make sure you clean up, he likes new and shiny things.*

```
$ npm install -g yo
```

## Usage

Install `generator-knockout-bootstrap`:
```
$ npm install -g generator-knockout-bootstrap
```

Make a new directory, and `cd` into it:
```
mkdir my-new-project && cd $_
```

Run `yo knockout-bootstrap`
```
$ yo knockout-bootstrap
```

Run `grunt` for building and `grunt serve` for preview

## Dependencies

* [Require.js](http://requirejs.org)
* [Sass version of bootstrap](https://github.com/twbs/bootstrap-sass)

### Options

The generator will ask if you want the following options:

* [Jade templating engine](http://jade-lang.org)
* [Sammy.js (local routing)](http://sammyjs.org)

## Getting To Know Yeoman

Yeoman has a heart of gold. He's a person with feelings and opinions, but he's very easy to work with. If you think he's too opinionated, he can be easily convinced.

If you'd like to get to know Yeoman better and meet some of his friends, [Grunt](http://gruntjs.com) and [Bower](http://bower.io), check out the complete [Getting Started Guide](https://github.com/yeoman/yeoman/wiki/Getting-Started).


## License

MIT

==> generator-knockout-bootstrap-0.1.0.tgz: package/README.md <==
# generator-knockout-bootstrap [![Build Status](https://secure.travis-ci.org/leszekhanusz/generator-knockout-bootstrap.png?branch=master)](https://travis-ci.org/leszekhanusz/generator-knockout-bootstrap)

> [Yeoman](http://yeoman.io) generator for Knockout.js with Twitter Bootstrap


## Getting Started

### What is Yeoman?

Trick question. It's not a thing. It's this guy:

![](http://i.imgur.com/JHaAlBJ.png)

Basically, he wears a top hat, lives in your computer, and waits for you to tell him what kind of application you wish to create.

Not every new computer comes with a Yeoman pre-installed. He lives in the [npm](https://npmjs.org) package repository. You only have to ask for him once, then he packs up and moves into your hard drive. *Make sure you clean up, he likes new and shiny things.*

```
$ npm install -g yo
```

## Usage

Install `generator-knockout-bootstrap`:
```
$ npm install -g generator-knockout-bootstrap
```

Make a new directory, and `cd` into it:
```
mkdir my-new-project && cd $_
```

Run `yo knockout-bootstrap`
```
$ yo knockout-bootstrap
```

Run `grunt` for building and `grunt serve` for preview

## Dependencies

* [Require.js](http://requirejs.org)
* [Sass version of bootstrap](https://github.com/twbs/bootstrap-sass)

### Options

The generator will ask if you want the following options:

* [Jade templating engine](http://jade-lang.com)
* [Sammy.js (local routing)](http://sammyjs.org)
* [Font Awesome icons](http://fortawesome.github.io/Font-Awesome)
* [Socket.io (full stack)](http://socket.io)
* [Knockout.validation](https://github.com/Knockout-Contrib/Knockout-Validation)

## Getting To Know Yeoman

Yeoman has a heart of gold. He's a person with feelings and opinions, but he's very easy to work with. If you think he's too opinionated, he can be easily convinced.

If you'd like to get to know Yeoman better and meet some of his friends, [Grunt](http://gruntjs.com) and [Bower](http://bower.io), check out the complete [Getting Started Guide](https://github.com/yeoman/yeoman/wiki/Getting-Started).


## License

MIT
